OC.L10N.register(
    "comments",
    {
    "Comments" : "Reacties",
    "You commented" : "Je reageerde",
    "{author} commented" : "{author} reageerde",
    "You commented on %1$s" : "Je reageerde op %1$s",
    "You commented on {file}" : "Je reageerde op {file}",
    "%1$s commented on %2$s" : "%1$s heeft gereageerd op %2$s",
    "{author} commented on {file}" : "{author} reageerde op {file}",
    "<strong>Comments</strong> for files" : "<strong>Reacties</strong> voor bestanden",
    "Files" : "Bestanden",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Je werd genoemd op \"{file}\", in een opmerking van een account dat intussen is verwijderd",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} noemde jou in een reactie op \"{file}\"",
    "Files app plugin to add comments to files" : "Bestanden app plugin om reacties aan bestanden toe te voegen",
    "Edit comment" : "Reactie bewerken",
    "Delete comment" : "Reactie verwijderen",
    "Cancel edit" : "Bewerking annuleren",
    "New comment" : "Nieuwe reactie",
    "Post comment" : "Reactie plaatsen",
    "@ for mentions, : for emoji, / for smart picker" : "@ voor vermeldingen, : voor emoji, / voor Smart Picker",
    "Could not reload comments" : "Kon reactie niet opnieuw laden",
    "Failed to mark comments as read" : "Kon reacties niet als gelezen markeren",
    "Unable to load the comments list" : "Kan reactielijst niet laden",
    "No comments yet, start the conversation!" : "Nog geen reacties, start de discussie!",
    "No more messages" : "Geen berichten meer",
    "Retry" : "Opnieuw proberen",
    "_1 new comment_::_{unread} new comments_" : ["1 nieuwe reactie","{unread} nieuwe reacties"],
    "Comment" : "Reactie",
    "An error occurred while trying to edit the comment" : "Er is een fout opgetreden bij het bewerken van de reactie",
    "Comment deleted" : "Reactie verwijderd",
    "An error occurred while trying to delete the comment" : "Er is een fout opgetreden bij het verwijderen van de reactie",
    "An error occurred while trying to create the comment" : "Er is een fout opgetreden bij het aanmaken van de reactie",
    "Write a comment …" : "Schrijf een reactie…"
},
"nplurals=2; plural=(n != 1);");
